FlFormNotifier class final

Inheritance

Constructors

FlFormNotifier()

Properties

hashCode int
The hash code for this object.
no setterinherited
hasListeners bool
Whether any listeners are currently registered.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value FlFormData
The current value stored in this notifier.
getter/setter pairinherited

Methods

add({required String text, required FlValidator validator, required String name, bool isLock = false}) → void
addListener(VoidCallback listener) → void
Register a closure to be called when the object changes.
inherited
changeAllToPure() → void
changeToPure(String name) → void
dispose() → void
Discards any resources used by the object.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
Call all the registered listeners.
inherited
remove(String name) → void
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited